Crate tezos_smart_rollup_panic_hook

Crate tezos_smart_rollup_panic_hook 

Hook to capture kernel panics, and write them to the debug log.

The hook will abort execution once the panic has been printed to the debug log.

Functions

panic_handler
Prints the panic info to the host’s debug log, and then aborts.